@@ -84,6 +84,7 @@ class Namelist(OrderedDict):
         self._logical_repr = {False: '.false.', True: '.true.'}
         self._index_spacing = False
         self._repeat_counter = False
+        self._split_strings = False
 
         # Namelist group spacing flag
         self._newline = False
@@ -349,28 +350,40 @@ class Namelist(OrderedDict):
         self.true_repr = value[1]
 
     @property
-    def true_repr(self):
-        """Set the string representation of logical true values.
+    def repeat_counter(self):
+        """Return whether the namelist uses repeat counters for arrays.
 
-        :type: ``str``
-        :default: ``.true.``
+        If True, then arrays with repeated values will use repeat tokens.  For
+        example, the array ``[1, 2, 2, 2]`` will be written as ``1, 3*2``.
 
-        This is equivalent to the second element of ``logical_repr``.
+        :type: ``bool``
+        :default: ``False``
         """
-        return self._logical_repr[1]
+        return self._repeat_counter
 
-    @true_repr.setter
-    def true_repr(self, value):
-        """Validate and set the logical true representation."""
-        if isinstance(value, str):
-            if not (value.lower().startswith('t') or
-                    value.lower().startswith('.t')):
-                raise ValueError("Logical true representation must start with "
-                                 "'T' or '.T'.")
-            else:
-                self._logical_repr[1] = value
+    @repeat_counter.setter
+    def repeat_counter(self, value):
+        """Set whether array output should be done in repeat form."""
+        if isinstance(value, bool):
+            self._repeat_counter = value
         else:
-            raise TypeError('Logical true representation must be a string.')
+            raise TypeError(r"repeat must be of type ``bool``")
+
+    @property
+    def split_strings(self):
+        """Split strings at the ``column_width`` over multiple lines.
+
+        :type: ``bool``
+        :default: ``False``
+        """
+        return self._split_strings
+
+    @split_strings.setter
+    def split_strings(self, value):
+        """Validate and set the split_strings flag."""
+        if not isinstance(value, bool):
+            raise TypeError('split_strings attribute must be a logical type.')
+        self._split_strings = value
 
     @property
     def start_index(self):
@@ -416,24 +429,46 @@ class Namelist(OrderedDict):
         self._start_index = value
 
     @property
-    def repeat_counter(self):
-        """Return whether the namelist uses repeat counters for arrays.
+    def true_repr(self):
+        """Set the string representation of logical true values.
 
-        If True, then arrays with repeated values will use repeat tokens.  For
-        example, the array ``[1, 2, 2, 2]`` will be written as ``1, 3*2``.
+        :type: ``str``
+        :default: ``.true.``
+
+        This is equivalent to the second element of ``logical_repr``.
+        """
+        return self._logical_repr[1]
+
+    @true_repr.setter
+    def true_repr(self, value):
+        """Validate and set the logical true representation."""
+        if isinstance(value, str):
+            if not (value.lower().startswith('t') or
+                    value.lower().startswith('.t')):
+                raise ValueError("Logical true representation must start with "
+                                 "'T' or '.T'.")
+            else:
+                self._logical_repr[1] = value
+        else:
+            raise TypeError('Logical true representation must be a string.')
+
+    @property
+    def uppercase(self):
+        """Print group and variable names in uppercase.
 
         :type: ``bool``
         :default: ``False``
-        """
-        return self._repeat_counter
 
-    @repeat_counter.setter
-    def repeat_counter(self, value):
-        """Set whether array output should be done in repeat form."""
-        if isinstance(value, bool):
-            self._repeat_counter = value
-        else:
-            raise TypeError(r"repeat must be of type ``bool``")
+        This is equivalent to the second element of ``logical_repr``.
+        """
+        return self._uppercase
+
+    @uppercase.setter
+    def uppercase(self, value):
+        """Validate and set the uppercase flag."""
+        if not isinstance(value, bool):
+            raise TypeError('uppercase attribute must be a logical type.')
+        self._uppercase = value
 
     def write(self, nml_path, force=False, sort=False):
         """Write Namelist to a Fortran 90 namelist file.
@@ -452,22 +487,6 @@ class Namelist(OrderedDict):
             if not nml_is_file:
                 nml_file.close()
 
-    @property
-    def uppercase(self):
-        """Print group and variable names in uppercase.
-
-        :type: ``bool``
-        :default: ``False``
-        """
-        return self._uppercase
-
-    @uppercase.setter
-    def uppercase(self, value):
-        """Validate and set the uppercase flag."""
-        if not isinstance(value, bool):
-            raise TypeError('uppercase attribute must be a logical type.')
-        self._uppercase = value
-
     def patch(self, nml_patch):
         """Update the namelist from another partial or full namelist.
 
@@ -649,6 +668,7 @@ class Namelist(OrderedDict):
                     self.RepeatValue(len(list(x)), val)
                     for val, x in itertools.groupby(v_values)
                 )
+
             for i_val, v_val in enumerate(v_values):
                 # Increase column width if the header exceeds this value
                 if len(v_header) >= self.column_width:
@@ -660,38 +680,47 @@ class Namelist(OrderedDict):
                     # NOTE: We allow non-strings to extend past the column
                     #   limit, but strings will be split as needed.
                     v_str = self._f90repr(v_val)
-                    if isinstance(v_val, str):
-                        idx = column_width - len(val_line)
+
+                    # Set a comma placeholder if needed
+                    if i_val < len(v_values) - 1 or self.end_comma:
+                        v_comma = ', '
+                    else:
+                        v_comma = ''
+
+                    if self.split_strings and isinstance(v_val, str):
+                        idx = column_width - len(val_line + v_comma.rstrip())
 
                         # Split the line along idx until we either exceed the
                         #   column width, or read the end of the string.
-                        while True:
-                            v_l, v_r = v_str[:idx], v_str[idx:]
-                            val_line += v_l
+                        v_l, v_r = v_str[:idx], v_str[idx:]
 
-                            if i_val < len(v_values) - 1 or self.end_comma:
-                                val_line += ', '
-
-                            if len(val_line) >= column_width:
-                                val_strs.append(val_line.rstrip())
-                                val_line = ''
-
-                            if v_r:
-                                v_str = v_r
-
-                                # Subsequent segments start on column zero
-                                idx = column_width
+                        if v_r:
+                            # Check if string can fit on the next line
+                            new_val_line = (
+                                ' ' * len(v_header) + v_str + v_comma
+                            )
+                            if len(new_val_line.rstrip()) <= column_width:
+                                val_strs.append(val_line)
+                                val_line = ' ' * len(v_header)
                             else:
-                                break
-                    else:
-                        val_line += v_str
-                        if i_val < len(v_values) - 1 or self.end_comma:
-                            val_line += ', '
+                                # Split string across multiple lines
+                                while v_r:
+                                    val_line += v_l
+                                    val_strs.append(val_line)
+                                    val_line = ''
+
+                                    idx = column_width - len(v_comma.rstrip())
+                                    v_l, v_r = v_r[:idx], v_r[idx:]
+
+                                v_str = v_l
+
+                    val_line += v_str + v_comma
 
                 # Line break
                 if len(val_line) >= column_width:
                     # Append current line to list of lines
                     val_strs.append(val_line.rstrip())
+
                     # Start new line with space corresponding to header
                     val_line = ' ' * len(v_header)
 
