@@ -10,7 +10,6 @@ from __future__ import print_function
 
 import warnings
 import copy
-import sys
 from string import whitespace
 import itertools
 
@@ -43,7 +42,10 @@ class Parser(object):
 
     @property
     def comment_tokens(self):
-        """List of tokens used to designate comments in a namelist file.
+        """Return a string of single-character comment tokens in the namelist.
+
+        :type: ``str``
+        :default: ``'!'``
 
         Some Fortran programs will introduce alternative comment tokens (e.g.
         ``#``) for internal preprocessing.
@@ -57,7 +59,7 @@ class Parser(object):
 
         Be aware that this is non-standard Fortran and could mangle any strings
         using the ``#`` characters.  Characters inside string delimiters should
-        be protected.
+        be protected, however.
         """
         return self._comment_tokens
 
@@ -70,7 +72,10 @@ class Parser(object):
 
     @property
     def default_start_index(self):
-        """Assumed starting index for a vector (Default: 1).
+        """Assumed starting index for a vector.
+
+        :type: ``int``
+        :default: 1
 
         Since Fortran allows users to set an arbitrary start index, it is not
         always possible to assign an index to values when no index range has
@@ -111,29 +116,13 @@ class Parser(object):
                             'type.')
         self._default_start_index = value
 
-    @property
-    def sparse_arrays(self):
-        """Store unset rows of multidimensional arrays as empty lists.
-
-        Enabling this flag will replace rows of unset values with empty lists,
-        and will also not pad any existing rows when other rows are expanded.
-
-        This is not a true sparse representation, but rather is slightly more
-        sparse than the default dense array representation.
-        """
-        return self._sparse_arrays
-
-    @sparse_arrays.setter
-    def sparse_arrays(self, value):
-        """Validate and enable spare arrays."""
-        if not isinstance(value, bool):
-            raise TypeError('sparse_arrays attribute must be a logical type.')
-        self._sparse_arrays = value
-
     @property
     def global_start_index(self):
         """Define an explicit start index for all vectors.
 
+        :type: ``int``, ``None``
+        :default: ``None``
+
         When set to ``None``, vectors are assumed to start at the lowest
         specified index.  If no index appears in the namelist, then
         ``default_start_index`` is used.
@@ -178,6 +167,9 @@ class Parser(object):
     def row_major(self):
         """Read multidimensional arrays in row-major format.
 
+        :type: ``bool``
+        :default: ``False``
+
         Multidimensional array data contiguity is preserved by default, so that
         column-major Fortran data is represented as row-major Python list of
         lists.
@@ -198,10 +190,35 @@ class Parser(object):
             else:
                 self._row_major = value
 
+    @property
+    def sparse_arrays(self):
+        """Store unset rows of multidimensional arrays as empty lists.
+
+        :type: ``bool``
+        :default: ``False``
+
+        Enabling this flag will replace rows of unset values with empty lists,
+        and will also not pad any existing rows when other rows are expanded.
+
+        This is not a true sparse representation, but rather is slightly more
+        sparse than the default dense array representation.
+        """
+        return self._sparse_arrays
+
+    @sparse_arrays.setter
+    def sparse_arrays(self, value):
+        """Validate and enable spare arrays."""
+        if not isinstance(value, bool):
+            raise TypeError('sparse_arrays attribute must be a logical type.')
+        self._sparse_arrays = value
+
     @property
     def strict_logical(self):
         """Use strict rules for parsing logical data value parsing.
 
+        :type: ``bool``
+        :default: ``True``
+
         The ``strict_logical`` flag will limit the parsing of non-delimited
         logical strings as logical values.  The default value is ``True``.
 
@@ -211,9 +228,9 @@ class Parser(object):
 
         When ``strict_logical`` is disabled, any value starting with ``.t`` or
         ``t`` is interpreted as ``True``, while any string starting with ``.f``
-        or ``f`` is interpreted as ``False``, as described in the Fortran
-        specification.  However, it can interfere with namelists which contain
-        strings which do not use delimiters.
+        or ``f`` is interpreted as ``False``, as described in the language
+        standard.  However, it can interfere with namelists which contain
+        non-delimited strings.
         """
         return self._strict_logical
 
@@ -262,6 +279,8 @@ class Parser(object):
             nml_file = open(nml_fname, 'r') if nml_is_path else nml_fname
             try:
                 return self._readstream(nml_file, nml_patch)
+            except StopIteration:
+                raise ValueError('End-of-file reached before end of namelist.')
 
             # Close the files we opened on any exceptions within readstream
             finally:
@@ -277,7 +296,10 @@ class Parser(object):
         >>> parser = f90nml.Parser()
         >>> data_nml = parser.reads('&data_nml x=1 y=2 /')
         """
-        return self._readstream(iter(nml_string.splitlines()))
+        try:
+            return self._readstream(iter(nml_string.splitlines(True)))
+        except StopIteration:
+            raise ValueError('End-of-file reached before end of namelist.')
 
     def _readstream(self, nml_file, nml_patch_in=None):
         """Parse an input stream containing a Fortran namelist."""
@@ -336,20 +358,29 @@ class Parser(object):
                 break
 
             # Create the next namelist
-            self._update_tokens()
+            try:
+                self._update_tokens()
+            except StopIteration:
+                raise ValueError('End-of-file after namelist group token `&`.')
             g_name = self.token
 
             g_vars = Namelist()
             v_name = None
 
             # TODO: Edit `Namelist` to support case-insensitive `get` calls
-            grp_patch = nml_patch.get(g_name.lower(), Namelist())
+            grp_patch = nml_patch.pop(g_name.lower(), Namelist())
 
             # Populate the namelist group
             while g_name:
 
                 if self.token not in ('=', '%', '('):
-                    self._update_tokens()
+                    try:
+                        self._update_tokens()
+                    except StopIteration:
+                        raise ValueError(
+                            'End-of-file before end of namelist group: \'&{}\''
+                            ''.format(g_name)
+                        )
 
                 # Set the next active variable
                 if self.token in ('=', '(', '%'):
@@ -377,9 +408,7 @@ class Parser(object):
                         g_vars[v_name] = v_val
                         v_strs = nmls._var_strings(v_name, v_val)
                         for v_str in v_strs:
-                            self.pfile.write(
-                                '{0}{1}\n'.format(nml_patch.indent, v_str)
-                            )
+                            self.pfile.write(v_str + '\n')
 
                     # Append the grouplist to the namelist
                     if g_name in nmls:
@@ -404,6 +433,15 @@ class Parser(object):
             except StopIteration:
                 break
 
+        if nml_patch:
+            # Append the contents to the namelist patch
+            print(file=self.pfile)
+            print(nml_patch, file=self.pfile)
+
+            # Now append the values to the output namelist
+            for grp in nml_patch:
+                nmls[grp] = nml_patch[grp]
+
         return nmls
 
     def _parse_variable(self, parent, patch_nml=None):
@@ -835,7 +873,7 @@ class Parser(object):
 
 # Support functions
 def prepad_array(var, v_start_idx, new_start_idx):
-    # NOTE: May be some way to use `pop` to avoid copying of index arrays...
+    """Return a resized vector based on the new start index."""
     prior_var = var[:]
 
     # Read the outer values
